----- NAZWA -----
 xlog - dziennik łączności dla radioamatorów napisany w GTK+

----- SKŁADNIA -----
 xlog [opcje]  <log1.xlog> <log2.xlog> ...

----- OPCJE I ARGUMENTY -----
 -h Pokazuje dostępne opcje i kończy działanie
 -v Podaje informacje o wersji i kończy działanie

Możesz także otwierać logi  z linii poleceń. Jeżeli nie podasz żadnego logu,
otwarte zostaną logi określone w oknie preferencji.

----- OPIS -----
xlog jest dziennikiem łączności dla radioamatorów. Główne okno programu składa
się z paska narzędziowego, ramki QSO i listy. Łączności zapisywane są jako
zwykłe pliki tekstowe. Możesz tworzyć, otwierać i zamykać logi kiedy tylko tego
potrzebujesz.

----- OBSŁUGA -----
Kiedy xlog zostanie uruchomiony po raz pierwszy ukazuje się puste okno. Musisz
wybrać z menu "Log->Nowy..." (Ctrl+N) aby utworzyć nowy log. 

                                       {xlog-newlogdialog.png}


Łączności wprowadzane są do logu poprzez ramkę QSO znajdującą się po lewej
stronie głównego okna. Kliknięcie na przycisku Data powoduje aktualizację pola
daty, zaś przycisk GMT aktualizację godziny według czasu uniwersalnego. Gdy
wprowadzisz znak wywoławczy, xlog na podstawie prefiksu wyświetla informacje
DXCC wraz z obliczoną odległością i kierunkiem anteny. W przypadku gdy do logu
wprowadzony jest QTH lokator, xlog oblicza azymut oraz odległość do lokatora
i wyświetla te informacje w oddzielnej ramce.

  {xlog-mainwindow.png}


Po wprowadzeniu informacji do wszystkich pól, naciśnij przycisk "Dodaj",
aby dodać QSO do listy po prawej stronie głównego okna. 

QSO mogą zostać usunięte z logu poprzez wskazanie wiersza na liście
i kliknięcie "Usuń".

Podobnie, pozycje logu mogą zostać zmienione poprzez wskazanie wiersza
na liście, zmienienie informacji dotyczących tego QSO w ramce i kliknięcie
"Aktualizuj".

Ostatecznie, wybranie z menu opcji "Edycja->Wyczyść wszystko" powoduje
wyczyszczenie wszystkich pól w ramce QSO.
 
----- SKRÓTY KLAWIATUROWE -----
Poniżej znajduje się lista dostępnych skrótów  klawiaturowych które możesz
stosować aby poruszać się po logu:

!  Control a lub <insert>: Dodaj QSO.
!  Control d lub <delete>: Usuń wybrane QSO.
!  Control h: Otwórz podręcznik.
!  Control i: Otwórz okno informacyjne.
!  Control k: Kliknij wszystkie przyciski i wypełnij pola wartościami
!             domyślnymi.
!  Control m: Połącz logi.
!  Control n: Utwórz nowy log.
!  Control o: Otwórz log.
!  Control q: Zamknij log.
!  Control r: Uaktywnij klucz CW.
!  Control u: Aktualizuj wybrane QSO.
!  Control s: Zapisz log.
!  Control t: Pokaż/Ukryj pasek narzędziowy.
!  Control w: Otwórz/zamknij okno z poprzednimi łącznościami.
!  Control x: Wyjdź z programu.
!  Control y: Wyczyść ramkę QSO.
!  Control f: Znajdź QSO w logu.
!  Tab:       Poruszaj się pomiędzy polami w ramce QSO.
!  Page Up:   Przewiń log do góry.
!  Page Down: Przewiń log do dołu.
!  Home:      Przejdź do początku logu.
!  End:       Przejdź na koniec logu.
!  Strzałka w górę: Wybierz następne QSO.
!  Strzałka w dół: Wybierz poprzednie QSO.
!  Alt+1, Alt+2, itd.: Przełączaj się pomiędzy logami.

----- PREFERENCJE -----
Aby możliwe było obliczenie poprawnej odległości do twojej lokalizacji, musisz
wprowadzić w zakładce "Informacja" w oknie preferencji twoją długość i szerokość
geograficzną. Możesz także określić w jakich jednostkach będzie podawana
odległość - w kilometrach bądź w milach morskich.

                             {xlog-preferencesdialog-info.png}


Kiedy zamierzasz robić łączności VHF/UHF i masz w logu pole do wpisywania QTH
lokatora, powinieneś wpisać własny QTH lokator w oknie preferencji.
Zakładka "Emisje/Pasma" pozwala na wybranie pola edycji do wprowadzania pasma
i emisji zamiast domyślnej listy opcji.

W zakładce "Logs" możesz określić, gdzie zapisywane będą twoje logi i które
z nich będą wczytywane przy starcie programu (w przypadku, gdy żadne logi nie
zostały podane w wierszu poleceń). Oczywiście musisz ponownie uruchomić program
i upewnić się, że wszystkie logi zostały przeniesione. Możesz posłużyć się
metaznakami lub listą logów oddzieloną przecinkami. Rozszerzenie .xlog będzie
dodawane automatycznie, np. kiedy posłużysz się metaznakami, 'p*' spowoduje
wczytanie wszystkich plików rozpoczynających się na 'p' i kończących na '.xlog'.

----- DRUKOWANIE -----
Możesz określić, czy chcesz drukować fragment logu bądź całość i wskazać, które
kolumny pojawią się na wydruku. Drukowanie może się odbywać w dwóch układach:
poziomym z  30 QSO i pionowym z 50 QSO na stronie. Długie linie będą rozdzielane
na kolejne kartki. Musisz upewnić się czy log zmieści się na danym rozmiarze
papieru i w razie potrzeby wybrać odpowiednią czcionkę bądź zmienić układ.

                                  {xlog-printdialog.png}


Utworzony plik postscriptowy jest wysyłany na domyślną drukarkę, ale możesz
także drukować do pliku. Utworzony wtedy zostanie plik log.ps w katalogu
$HOME/.xlog.

Dla logów z zawodów możesz dodatkowo zaznaczyć do wydruku dwie puste kolumny
zatytułowane 'Multiplier' i 'Points' do policzenia twojego wyniku. Gdy
wybierzesz pionowy układ wydruku zalecane jest usunięcie kolumn "QSL wysłana",
"QSL otrzymana" oraz "Uwagi". W przeciwnym razie log nie zmieści się na stronie.

----- ETYKIETY QSL -----
gLabels to aplikacja dla Gnome służąca do drukowania wizytówek i etykiet, zobacz
stronę http://glabels.sourceforge.net aby uzyskać więcej informacji.
Została zaprojektowana do drukowania na różnorodnych samoprzylepnych etykietach
oraz arkuszach do wizytówek przeznaczonych dla drukarek laserowych
i atramentowych, które można zakupić w sklepach z artykułami biurowymi. Program
xlog współpracuje z gLabels w wersji powyżej 0.4.

Możesz użyć polecenia "Zapisz jako..." aby wyeksportować log do pliku typu
"TSV". Spowoduje to zapisanie twojego logu w pliku z polami oddzielonymi znakami
tabulacji. Pozycje, które chcesz zapisać podczas eksportu, możesz określić
w zakładce "Zapisz jako" w oknie "Ustawienia->Okna dialogowe".
Zapisany w ten sposób plik możesz zaimportować do programu gLabels przy
zastosowaniu szablonu nazwanego qsllabels.glabels i umieszczonego w katalogu
/usr/[local/]share/xlog.

1 - Uruchom gLabels
2 - Otwórz qsllabels.glabels
3 - Wybierz "Merge properties" z menu "Objects"
4 - Wskaż położenie wyeksportowanego z xlog pliku etykiet
5 - Nie zmieniaj żadnych z pozostałych pól, po prostu naciśnij "OK"
6 - Teraz możesz rozpocząć drukowanie

Możesz zmodyfikować domyślny układ arkusza. Wybierz w tym celu z menu
"Edit->Select All", kliknij "New", wskaż odpowiedni typ arkusza z listy, wybierz
"Edit->Paste" aby skopiować pola do nowego projektu i dopasuj za pomocą myszy
położenie poszczególnych pól do nowego rozmiaru etykiety. Zapisz ten plik,
aby móc go później stosować jako szablon do twoich etykiet dla kart QSL.

----- UKŁAD LOGU -----
Edytor układu logu, dostępny w menu "Narzędzia", służy do wskazania, które
kolumny logu będą wyświetlane bądź ukryte. Dwie kolumny pozwalają na samodzielne
określenie ich nazwy przez użytkownika. Zmiany układu kolumn zaczną obowiązywać
w przypadku, gdy zapiszesz swój log.

                             {xlog-logeditor.png}


Należy zwrócić uwagę, że pole to można opisać za pomocą wybranej ze specyfikacji
ADIF nazwy. Będzie ona użyta gdy będziemy chcieli eksportować log do formatu
ADIF. Opis standardu znajduje się na stronie:
http://www.hosenose.com/adif/adif.html, sekcja 3: Field Definitions.

Edytor układu logu używany jest także do określenia szerokości kolumn. Podana
wartość powinna być większa niż 20. Zmiana szerokości kolumn dotyczy wszystkich
otwartych w danej chwili logów. Wyjątek stanowi kolumna z numerem, która pozwala
na wprowadzenie wartości zerowej. Spowoduje to jej ukrycie.

----- KONTROLA POWTÓRZEŃ -----
Możliwa jest kontrola w logu pod katem występowania powtórzeń, za pomocą
polecenia w menu "Narzędzia". Istnieje kilka ograniczeń dotyczących pola
częstotliwości w przypadku, gdy ma być uwzględniane przy kontroli. Częstotliwość
w obu przypadkach powinna być oddzielona za pomocą kropki po liczbie MHz lub
zawierać 3, 6 bądź 9 cyfr po liczbie MHz.

                                       {xlog-dupecheckdialog.png}


Kiedy używana jest biblioteka hamlib, liczba cyfr w polu częstotliwości może
zostać określona w zakładce "Hamlib" okna preferencji.

----- SORTOWANIE LOGU -----
Jeżeli wybierzesz polecenie "Narzędzia->Sortuj według daty", twój log zostanie
posortowany chronologicznie zgodnie z datą i czasem łączności. Sortowanie
zakłada, że cały log został stworzony z tymi samymi ustawieniami regionalnymi.
Wobec tego, data w logu powinna mieć format "dd mm yyyy" zgodny z twoimi
ustawieniami regionalnymi, np. "01 May 2004" w Anglii, "01 maj 2004" w Polsce,
itp. Obecną nazwę miesiąca dla twoich ustawień językowych możesz sprawdzić
za pomocą polecenia wydanego na konsoli:

					"date --date='01 May'".

Godzina powinna być w formacie "HHMM", np. "1423". Posortowany log zostaje
oznaczony jako zmodyfikowany. Zalecane jest zapisanie logu pod nową zmienioną
nazwą, przez co oryginalny log pozostanie niezmieniony. Powinieneś sprawdzić
poprawność dat i czasów w nowym logu zanim nadpiszesz oryginalny. Jeżeli log nie
jest posortowany poprawnie, uruchom xlog w terminalu aby zobaczyć czy procedura
sortowania nie zwraca jakichś błędów.

----- WARTOŚCI DOMYŚLNE -----
Polecenia "Ustawienia->Domyślne" pokazuje okno w którym możesz podać domyślne
wartości przy logowaniu. Wartości te są używane kiedy wybierzesz z menu
polecenie "Edycja->Kliknij wszystko".

                                       {xlog-defaultsdialog.png}


----- POPRZEDNIE ŁĄCZNOŚCI -----
Kiedy wybierzesz z menu "Narzędzia" polecenie "Poprzednie łączności" wyświetlone
zostanie okno zawierające posortowaną listę łączności z wpisywanym w oknie logu
znakiem. Funkcja ta jest szczególnie przydatna podczas zawodów.

                        {xlog-workedwindow.png}


Liczba kolumn pokazywana w tym oknie może być dostosowana poprzez menu
"Ustawienia->Okna dialogowe" (pierwsza strona).
 
----- WYSZUKIWANIE PODCZAS WPISYWANIA -----
Kiedy wpisujesz znak wywoławczy, log jest przeszukiwany w celu odnalezienia
odpowiedników. Kiedy dany znak zostanie znaleziony, twoje pola Imię, QTH,
Lokator i Uwagi zostaną automatycznie wypełnione. Możesz wyłączyć tą funkcję
w oknie preferencji.

----- HAMLIB -----
Gdy xlog został skompilowany ze wsparciem hamlib, możesz poprzez port szeregowy
odczytywać częstotliwość twojego radia. Na zakładce "Hamlib" w oknie preferencji
musisz określić model swojego radia oraz port do którego jest ono podłączone.
Jeżeli zamierzasz używać radia RPC, powinieneś wskazać jako port localhost.

Na tej samej stronie istnieje możliwość włączenia dokowanego na pasku statusu
wskaźnika częstotliwości oraz S-metra.

                             {xlog-preferencesdialog-hamlib.png}


Gdy włączona została obsługa hamlib, do ramki QSO dodane zostaną 3 przyciski.
Pozwalają one na wypełnienie pola z częstotliwością, emisją i siłą sygnału
wartościami pobranymi z radia. Jeżeli w twoim logu przechowywana jest informacja
o mocy (wymagana w niektórych krajach), w ramce QSO umieszczony zostaje także
przycisk pozwalający na pobranie aktualnej mocy nadajnika.

Możliwe jest również ciągłe pobieranie wszystkich informacji w zadanych
odstępach czasu, bądź też odebranie wszystkich informacji z radia, kiedy wybrane
zostanie polecenie "Edycja->Kliknij wszystko" lub kombinacja klawiszy Ctrl+k.

Twoje ustawienia portu mogą być konfigurowane w zakładce "Hamlib" okna
preferencji. Możesz tam podać takie parametry jak: rts_state=ON,timeout=600,
serial_speed=19200.

----- TESTOWANIE HAMLIB -----
Na początku musisz prawdopodobnie przeczytać instrukcję obsługi do twojego
radia, aby dowiedzieć się w jaki sposób połączyć go z portem szeregowym
w komputerze. W przypadku mojego urządzenia Kenwood, wymagany jest standardowy
9-pinowy kabel szeregowy. Musisz dodatkowo przydzielić uprawnienia do portu
szeregowego, w moim systemie oznaczało to dodanie własnego konta użytkownika
do grupy dialout, za pomocą polecenia:

	adduser 'username' dialout

Następnie możesz przetestować hamlib z rigctl, programem dołączonym
do biblioteki. Sprawdź jakie urządzenia są odsługiwane:

	rigctl --list

W kolejnym kroku uruchom rigctl z numerem twojego modelu, np. '210' w przypadku
Kenwood'a TS-870S podłączonego do portu COM2:

	rigctl -r /dev/ttyS1 -m 210

Teraz możesz sprawdzić czy odbierane są: emisja, PTT, częstotliwość, siła
sygnału i moc (wszystkie wykorzystywane przez xlog).

	'f': pobiera częstotliwość
	'm': pobiera emisję
	't': pobiera PTT (stan TX/RX)
	'l' i potem 'STRENGTH': odbiera siłę sygnału (-54=S0 i 0=S9)
	'l' i potem 'RFPOWER': odbiera moc nadajnika (0.39 = 100 W)

W FAQ hamlib znajdującym się na stronie http://hamlib.sf.net/faq.html znajdziesz
wiele odpowiedzi na często występujące problemy. Możesz także zadać pytanie
na liście dyskusyjnej poświęconej hamlib, odwiedź w tym celu:
http://lists.sourceforge.net/lists/listinfo/hamlib-developer.

----- OKNO KLUCZA CW -----
Okno klucza CW, dostępne w menu Narzędzia, jest w rzeczywistości prostym
(używanym podczas zawodów) interfejsem dla cwdaemon. Możesz w nim przypisać
wiadomości CW do wszystkich klawiszy funkcyjnych oraz kontrolować swoją
prędkość nadawania. Kliknięcie na przycisku stop, bądź posłużenie się klawiszem
'ESC' spowoduje przerwanie wysyłania wiadomości. Możesz także obserwować
licznik dla numerów seryjnych, toggle box dla krótkich numerów porządkowych
oraz menu do wyboru trybu CQ bądź S&P (wyszukiwanie i wołanie)

                                  {xlog-keyerwindow.png}


Polu tekstowe na dole okna może posłużyć do wpisywania znaków. Polecenia
przypisane do klawiszy funkcyjnych mogą zawierać następujące makra:

!  % - mój znak
!  @ - znak korespondenta
!  # - numer z licznika

Numer z licznika jest automatycznie zwiększany. Wartości domyślne, podane
w preferencjach, mogą zostać użyte przy podawaniu domyślnych raportów podczas
zawodów, makro # może zostać użyte w polu TX(RST) tego okna.

----- PROWADZENIE ZAWODÓW W TRYBIE CQ -----
 - ustaw kursor w polu znak
 - <enter> w pustym polu znak wywoła <F1>: "CQ de PG4I PG4I test"
 - wprowadź usłyszany znak i naciśnij <enter>
 - <F3> spowoduje wysłanie: "PA0R 5nntt1"
 - wymieniane pola zostaną wypełnione na podstawie wartości domyślnych
 - xlog przejdzie do ostatniego wymienianego pola <RX(RST)>
 - wprowadź wymieniany numer który usłyszałeś i naciśnij <enter>
 - xlog uzupełni pola z datą, czasem i częstotliwością
 - <CQTU> spowoduje teraz wysłanie: "tu PG4I test"
 - użyj <ctl+a> lub <insert> aby wprowadzić QSO
 - licznik zostanie zwiększony
 - wszystkie pola zostaną wyczyszczone a xlog przejdzie do pola znak

----- PROWADZENIE ZAWODÓW W TRYBIE S&P -----
 - ustaw kursor w polu znak
 - wprowadź usłyszany znak i naciśnij <enter>
 - <F6> spowoduje wysłanie: "PG4I"
 - wymieniane pola zostaną wypełnione na podstawie wartości domyślnych
 - xlog przejdzie do ostatniego wymienianego pola <RX(RST)>
 - wypełnij pole i naciśnij <enter>
 - <S&PTU> spowoduje wysłanie: "TU 5nntt1"
 - użyj <ctl+a> lub <insert> aby wprowadzić QSO
 - licznik zostanie zwiększony
 - wszystkie pola zostaną wyczyszczone a xlog przejdzie do pola znak

----- WYMIANA DANYCH -----
xlog potrafi wymieniać dane z twpsk (wersja 2.0 lub wyższa) autorstwa WA0EIR.
Gdy wprowadzony zostanie znak wywoławczy, pokaże się on także w oknie nadawania
twpsk (tam gdzie wpisujesz swój tekst) gdy tylko naciśniesz Shift+Alt+h.
Naciśnięcie Shift+Alt+o spowoduje wypisanie 'wołany_znak de mój_znak'.

gmfsk autorstwa OH2BNS (począwszy od wersji 0.4) potrafi przesłać informacje
o łączności do xlog, gdy naciśniemy przycisk "Log entry". Marote (wersja 2.3
lub późniejsza), program do sterowania radiem Electraft K2 autorstwa AB6CV,
posiada identyczną możliwość, gdy naciśniemy przycisk "Log QSO".

ktrack autorstwa LX2GT (począwszy od wersji 0.2.1) potrafi wymieniać informacje
o satelitach z programem xlog. Aby taka operacja była możliwa musisz włączyć
2 dodatkowe własne pola w logu (menu "Narzędzia->Układ logu"). Następnie wybierz
na ostatniej stronie okna preferencji opcję "Dodaj dane do ramki QSO".

----- IMPORT i EKSPORT plików -----
xlog obsługuje import danych z następujących formatów plików: twlog, editest,
ADIF, Trlog (tlf), EDI (format stosowany w zawodach na pasmach VHF i wyższych
zalecany przez IARU region 1) oraz Cabrillo. Logi mogą być eksportowane do
formatów: EDI, ADIF i Cabrillo. Właściwy format pliku powinien zostać wybrany
z rozwijanej listy opcji (przy użyciu okna "Zapisz jako...") podczas importu
bądź eksportu logu.

  {xlog-openlogdialog.png}


! Przed importem proszę sprawdzić swój log pod względem poprawności formatu.
! Okno "Log->Otwórz" zawiera widget umożliwiający podgląd pierwszych 10
! linijek pliku, dzięki czemu możesz skontrolować otwierany log.

Kiedy zamierzać eksportować log do formatu EDI, powinieneś włączyć pole lokatora
w logu. Umożliwi to programowi Xlog automatyczne obliczenie odległości
i dodatnie tej informacji do logu. Kiedy eksportujesz log do formatu ADIF możesz
zdecydować czy dokonać konwersji częstotliwości na pasma. Posłuż sie w tym celu
oknem "Ustawiania->Okna dialogowe" i na zakładce "Zapisz jako" zaznacz
odpowiednią opcję.

Format eksportu TSV (Tab Separated Value) jest używany przez gLabels (zobacz
rozdział o etykietach QSL). Możesz jednak posłużyć się tym formatem także by
zaimportować swoje dane do arkusza kalkulacyjnego. Na stronie "Zapisz jako"
w oknie "Ustawienia->Okna dialogowe" masz możliwość zaznaczenia które z pół
zostaną wyeksportowane.

----- ŁĄCZENIE LOGÓW -----
xlog pozwala na połączenie 2 logów poprzez wybranie z menu polecenia Log ->
Łączenie. Będziesz musiał wskazać nazwy dwóch plików. Nowy log po połączeniu
zostanie nazwany "log1+log2".

                                  {xlog-mergelogdialog.png}


Zanim będziesz zamierzał połączyć logi, musisz upewnić się, że zawierają taką
samą liczbę kolumn. Posłuż się poleceniem "Układ logu" aby dodać lub usunąć
kolumny. Po połączeniu, możesz użyć polecenia "Narzędzia->Sortuj według daty"
by posortować log.


----- PLIKI -----
/usr/[local/]share/xlog/dxcc/cty.dat zawiera wpisy DXCC czytane przez xlog.
Ten plik może być uzupełniany poprzez dodawanie pozycji do
/usr/[local/]share/xlog/dxcc/xlog.dat.
 
----- CZCIONKI I MOTYWY -----
Czcionki używane przez xlog są zgodne z wybranym motywem GTK. W przypadku, gdy
używasz Gnome2 uruchom program gnome-font-properties. W przeciwnym przypadku
otwórz do edycji plik ~/.gtkrc-2.0 i dodaj poniższą linijkę:

	gtk-font-name = "Times New Roman 14"

lub z jakąkolwiek inną wartością. GNOME 2 stosuje swoje własne ustawienia dla
programów GTK2 poprzez gnome-settings-daemon. Kiedy deamon jest uruchomiony,
programy GTK2 używają ustawień GNOME zamiast zawartych w pliku .gtkrc-2.0.

Istnieje także aplikacja gtk-theme-switch2, którą możesz użyć aby dostosować 
wygląd i czcionkę, gdy używasz Gnome bądź nie.

----- AUTORZY -----
xlog został napisany przez Joop'a Stakenborg <pg4i at amsat.org> bądź <pa3aba at
debian.org> oraz Stephane'a Fillod <f8cfe at free.fr>. Wielu ludzi wniosło swój
własny wkład w rozwój programu, możesz zobaczyć ich nazwiska w pliku THANKS.


----- TŁUMACZENIE -----
Plik pomocy został przetłumaczony z języka angielskiego przez Bogusława Ciastka
SQ5TB < ciacho at z.pl >.
