Poniżej znajduje się kilka pytań opracowanych na podstawie list dyskusyjnych
xlog-discussion i hamlib-developer.

- Mam zainstalowaną bibliotekę hamlib, ale xlog nie potrafi jej znaleźć.

Jeżeli instalowałeś bibliotekę hamlib ze źródeł została ona prawdopodobnie
umieszczona w katalogu /usr/local/lib. Musisz dodać "/usr/local/lib" do pliku
/etc/ld.so.conf i uruchomić ldconfig jako root.

- Gdy instaluję xlog z rpm, otrzymuję informację, że biblioteka hamlib nie jest
zainstalowana.

Jeżeli jesteś pewny, że biblioteka hamlib jest poprawnie zainstalowana,
zainstaluj xlog z rpm przy użyciu polecenia:
'rpm -ivh --nodeps'.

- Gdy instaluję xlog z rpm, otrzymuję informację o niespełnionych zależnościach.

Pakiety rpm były budowane dla ostatniej wersji Debiana, która może używać innych
wersji bibliotek niż twoja dystrybucja. W takim przypadku, najlepszym
rozwiązaniem będzie kompilacja xlog ze źródeł. Aby zobaczyć szczegóły, przejrzyj
plik INSTALL.

- Położenie geograficzne i odległość wyglądają na niedokładne dla mojej
lokalizacji.

Informacja o strefie czasowej pochodzi z pliku cty.dat. Obecnie plik ten nie
zawiera informacji dla poszczególnych stanów USA i kanadyjskich okręgów
wywoławczych. Do tego czasu możesz spróbować dodać informację do pliku cty.dat.
Na przykład, jeżeli zamieszkujesz w VE7:

Canada|VE7:              05:  09:  NA:   xx.xx:    yy.yy:     7.0:  VE:
    VE7;VA7;

Uzupełnij ją poprawnymi danymi o strefach, współrzędnych i strefie czasowej.
Wadą takiego rozwiązania jest to, że informacja ta będzie nadpisana przy
następnej instalacji bądź aktualizacji xlog. Mam nadzieję, że problem ten
zostanie naprawiony w następnej wersji.

- Zaktualizowałem xlog i teraz wszystkie moje ustawienia zniknęły!

Najprawdopodobniej dokonałeś aktualizacji wersji wcześniejszej niż 0.9.6.
Obecnie xlog do przechowywania swojej konfiguracji stosuje format xml, musisz
więc od nowa skonfigurować swój program.

- Drukowanie z xlog nie działa, jakieś wskazówki?

Xlog drukuje do domyślnej drukarki w twoim systemie. Jeżeli korzystasz
z Gnome i Cups, spróbuj posłużyć się małym program gnome-cups-manager aby
skonfigurować drukarki. W przypadku, gdy korzystasz z lpd lub lprng, musisz
upewnić się, że w pliku /etc/printcap znajduje się wpis nazwany 'lp'. Jeżeli
i to nie rozwiąże problemu, spróbuj wydruku do pliku postscript, otwórz ten
plik i wydrukuj w twojej ulubionej przeglądarce.
